@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Andy Spencer <andy753421@gmail.com>
+ * Copyright (C) 2009-2011 Andy Spencer <andy753421@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -349,7 +349,7 @@ void grits_viewer_set_rotation(GritsViewer *viewer, gdouble x, gdouble y, gdoubl
 void grits_viewer_get_rotation(GritsViewer *viewer, gdouble *x, gdouble *y, gdouble *z)
 {
 	g_assert(GRITS_IS_VIEWER(viewer));
-	g_debug("GritsViewer: get_rotation");
+	//g_debug("GritsViewer: get_rotation");
 	*x = viewer->rotation[0];
 	*y = viewer->rotation[1];
 	*z = viewer->rotation[2];
@@ -542,15 +542,12 @@ gpointer grits_viewer_add(GritsViewer *viewer, GritsObject *object,
  *
  * Returns: the #GritsObject referenced by the handle
  */
-GritsObject *grits_viewer_remove(GritsViewer *viewer, gpointer _object)
+GritsObject *grits_viewer_remove(GritsViewer *viewer, GritsObject *object)
 {
-	GritsObject *object = _object;
 	GritsViewerClass *klass = GRITS_VIEWER_GET_CLASS(viewer);
 	if (!klass->remove)
 		g_warning("GritsViewer: remove - Unimplemented");
-	klass->remove(viewer, object->ref);
-	object->ref    = NULL;
-	object->viewer = NULL;
+	klass->remove(viewer, object);
 	return object;
 }
 
